autowisp.database.data_model.hdf5_attributes module — AutoWISP documentation

# autowisp.database.data_model.hdf5_attributes module

## Class Inheritance Diagram

Define the hdf5_attributes table.

class autowisp.database.data_model.hdf5_attributes.HDF5Attribute(**kwargs)

  Bases: `DataModelBase`

  The table describing how to add attributes in HDF5 files.

  __str__()

    Print the contents of the given attribute.

  description

    A brief description of what this attribute tracks.

  dtype

    The data type to use for this dataset. See h5py for possible values and their meanings.

  hdf5_structure_version_id

    Which structure version of which pipeline product is this element configuration for.

  id

    A unique identifier for each row.

  name

    The name to give to use for this attribute within the HDF5 file.

  parent

    The full absolute path to the group or dataset to add this attribute to.

  pipeline_key

    How is this attribute referred to by the pipeline.

  structure_version
  timestamp

    When record was last changed